package com.xkrs.controller;

import com.xkrs.dao.QcInspectionFileDao;
import com.xkrs.encapsulation.PromptMessageEnum;
import com.xkrs.model.qo.QcInspectionFileQo;
import com.xkrs.service.QcInspectionFileService;
import com.xkrs.util.ExcelUploadUtil;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.transaction.Transactional;
import java.io.IOException;
import java.util.Locale;

import static com.xkrs.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * @Author: XinYi Song
 * @Date: 2022/1/20 16:01
 */
@RestController
public class QcInspectionFileController {

    @Resource
    private QcInspectionFileService inspectionFileService;

    @Resource
    private QcInspectionFileDao inspectionFileDao;

    /**
     * 上传模板信息
     *
     * @param inspectionFileQo
     * @param fileExcel
     * @return
     * @throws IOException
     */
    @PostMapping("/insertFileExcel")
    public String insertFileExcel(QcInspectionFileQo inspectionFileQo, @RequestParam("fileExcel") MultipartFile fileExcel) throws IOException {
        return inspectionFileService.insertFileExcel(inspectionFileQo, fileExcel);
    }

    /**
     * 修改上传的模板信息
     *
     * @param inspectionFileQo
     * @param fileExcel
     * @return
     * @throws IOException
     */
    @PostMapping("/updateFileUploadPath")
    @Transactional(rollbackOn = Exception.class)
    public String updateFileUploadPath(QcInspectionFileQo inspectionFileQo, @RequestParam("fileExcel") MultipartFile fileExcel) throws IOException {
        String lotNo = inspectionFileQo.getLotNo();
        String machineNo = inspectionFileQo.getMachineNo();
        String materialNo = inspectionFileQo.getMaterialNo();
        String modelNo = inspectionFileQo.getModelNo();
        String partNo = inspectionFileQo.getPartNo();
        Locale locale = LocaleContextHolder.getLocale();
        String file = ExcelUploadUtil.memoryFile(fileExcel);
        inspectionFileDao.updateTemplatePath(lotNo, machineNo, materialNo, modelNo, partNo, file);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "修改成功！", locale);
    }

    /**
     * 导出excel
     *
     * @param inspectionFileQo
     * @return
     */
    @PostMapping("/exportExcel")
    public String exportExcel(@RequestBody QcInspectionFileQo inspectionFileQo) throws IOException, InvalidFormatException {
        return inspectionFileService.exportExcel(inspectionFileQo);
    }
}
