package com.xkrs.controller;

import com.xkrs.dao.QcInspectionItemDictDao;
import com.xkrs.encapsulation.PromptMessageEnum;
import com.xkrs.model.entity.QcInspectionItemDict;
import com.xkrs.model.qo.QcInspectionItemDictQo;
import com.xkrs.service.QcInspectionItemDictService;
import com.xkrs.util.Query;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.transaction.Transactional;
import java.util.List;
import java.util.Locale;

import static com.xkrs.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * @Author: XinYi Song
 * @Date: 2022/1/19 10:54
 */
@RestController
public class QcInspectionItemDictController {

    @Resource
    private QcInspectionItemDictService inspectionItemDictService;

    @Resource
    private QcInspectionItemDictDao inspectionItemDictDao;

    @Resource
    private Query query;

    /**
     * 添加字典变量数据
     *
     * @param inspectionItemDictQo
     * @return
     */
    @PostMapping("/insertDataDict")
    public String insertDataDict(@RequestBody QcInspectionItemDictQo inspectionItemDictQo) {
        return inspectionItemDictService.insertDataDict(inspectionItemDictQo);
    }

    /**
     * 动态多条件查询字典信息
     *
     * @param inspectionItemCode
     * @param inspectionItemName
     * @return
     */
    @GetMapping("/selectDataDict")
    public String selectDataDict(@RequestParam("inspectionItemCode") String inspectionItemCode, @RequestParam("inspectionItemName") String inspectionItemName) {
        Locale locale = LocaleContextHolder.getLocale();
        List<QcInspectionItemDict> qcInspectionItemDict = query.selectDataDict(inspectionItemCode, inspectionItemName);
        if (qcInspectionItemDict == null || qcInspectionItemDict.size() == 0) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "暂时还没有该型号类型的字典信息！", locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, qcInspectionItemDict, locale);
    }

    /**
     * 根据id查询字典信息，用于数据回显，方便进行修改操作
     *
     * @param id
     * @return
     */
    @GetMapping("/selectDataDictById")
    public String selectDataDictById(@RequestParam("id") Integer id) {
        Locale locale = LocaleContextHolder.getLocale();
        QcInspectionItemDict qcInspectionItemDict = inspectionItemDictDao.findById(id);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, qcInspectionItemDict, locale);
    }

    /**
     * 根据id修改字典信息
     *
     * @param inspectionItemDictQo
     * @return
     */
    @PostMapping("/updateDict")
    @Transactional(rollbackOn = Exception.class)
    public String updateDict(@RequestBody QcInspectionItemDictQo inspectionItemDictQo) {
        Locale locale = LocaleContextHolder.getLocale();
        inspectionItemDictDao.updateDictById(inspectionItemDictQo.getId(), inspectionItemDictQo.getInspectionItemName());
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "修改成功！", locale);
    }
}
