package com.xkrs.service.impl;

import com.xkrs.dao.QcInspectionDataSourceDao;
import com.xkrs.dao.QcInspectionFileDao;
import com.xkrs.encapsulation.PromptMessageEnum;
import com.xkrs.model.entity.QcInspectionDataSource;
import com.xkrs.model.entity.QcInspectionFile;
import com.xkrs.model.entity.QcInspectionItemDict;
import com.xkrs.model.qo.QcInspectionFileQo;
import com.xkrs.service.QcInspectionFileService;
import com.xkrs.util.ExcelUploadUtil;
import com.xkrs.util.ExportExcel;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.transaction.Transactional;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;

import static com.xkrs.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * @Author: XinYi Song
 * @Date: 2022/1/20 15:24
 */
@Service
public class QcInspectionFileServiceImpl implements QcInspectionFileService {

    @Resource
    private QcInspectionFileDao inspectionFileDao;

    @Resource
    private QcInspectionItemDict inspectionItemDict;

    @Resource
    private QcInspectionDataSourceDao inspectionDataSourceDao;

    /**
     * 添加模板信息
     *
     * @param inspectionFileQo
     * @return
     */
    @Override
    public String insertFileExcel(QcInspectionFileQo inspectionFileQo, MultipartFile fileExcel) throws IOException {
        String lotNo = inspectionFileQo.getLotNo();
        String machineNo = inspectionFileQo.getMachineNo();
        String materialNo = inspectionFileQo.getMaterialNo();
        String modelNo = inspectionFileQo.getModelNo();
        String partNo = inspectionFileQo.getPartNo();
        Locale locale = LocaleContextHolder.getLocale();
        List<QcInspectionFile> qcInspectionFiles = inspectionFileDao.selectFile(lotNo, machineNo, materialNo, modelNo, partNo);
        if (qcInspectionFiles != null || qcInspectionFiles.isEmpty()) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_EXIT, "已存在该产品的模板!", locale);
        }
        if (fileExcel == null) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "模板不能为空！", locale);
        }
        String file = ExcelUploadUtil.memoryFile(fileExcel);
        QcInspectionFile fileEntity = new QcInspectionFile();
        fileEntity.setId(inspectionFileQo.getId());
        fileEntity.setLotNo(lotNo);
        fileEntity.setMachineNo(machineNo);
        fileEntity.setMaterialNo(materialNo);
        fileEntity.setModelNo(modelNo);
        fileEntity.setPartNo(partNo);
        fileEntity.setTemplatePath(file);
        inspectionFileDao.save(fileEntity);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "添加成功！", locale);
    }

    /**
     * 导出excel
     *
     * @param inspectionFileQo
     * @return
     */
    @Transactional(rollbackOn = Exception.class)
    @Override
    public String exportExcel(QcInspectionFileQo inspectionFileQo) throws IOException, InvalidFormatException {
        String lotNo = inspectionFileQo.getLotNo();
        String machineNo = inspectionFileQo.getMachineNo();
        String materialNo = inspectionFileQo.getMaterialNo();
        String modelNo = inspectionFileQo.getModelNo();
        String partNo = inspectionFileQo.getPartNo();
        Locale locale = LocaleContextHolder.getLocale();
        List<QcInspectionFile> qcInspectionFiles = inspectionFileDao.selectFile(lotNo, machineNo, materialNo, modelNo, partNo);
        if (qcInspectionFiles == null || qcInspectionFiles.isEmpty()) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "暂时没有该产品的模板，请添加！", locale);
        }
        String templatePath = qcInspectionFiles.get(0).getTemplatePath();
        List<QcInspectionDataSource> inspectionDataSources = inspectionDataSourceDao.selectDataSource(lotNo, machineNo, materialNo, modelNo, partNo);
        if (inspectionDataSources == null || inspectionDataSources.isEmpty()) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "暂时没有该产品的信息！", locale);
        }
        Map<String, String> map = new HashMap<>();
        for (QcInspectionDataSource inspectionDataSource : inspectionDataSources) {
            map.put(inspectionDataSource.getInspectionItemCode(), inspectionDataSource.getInspectValue());
        }
        String fill = ExportExcel.exportToProveExcel(map, templatePath);
        inspectionFileDao.updateFilePath(lotNo, machineNo, materialNo, modelNo, partNo, fill);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, fill, locale);
    }
}
